multicamera library

Classes

Camera
A camera instance that provides access to the underlying platform.
CameraPreview
A widget that displays a live camera preview.

Enums

CameraDirection
Specifies the direction a camera is facing.

Typedefs

BarcodesScannedCallback = void Function(List<String>)
Callback function that is invoked when barcodes are scanned in the camera feed.
FaceDetectedCallback = void Function(bool)
Callback function that is invoked when a face is detected in the camera feed.
TextRecognizedCallback = void Function(List<String>)
Callback function that is invoked when text is recognized in the camera feed.