Camera class

A camera instance that provides access to the underlying platform.

Example usage:

final camera = Camera(direction: CameraDirection.front);
await camera.initialize();
// Use camera with CameraPreview widget
Inheritance

Constructors

Camera({CameraDirection direction = CameraDirection.front, bool paused = false})
Creates a new Camera instance.

Properties

direction CameraDirection
The direction the camera is facing.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
id int?
A unique ID referring to this camera instance.
no setter
initialized bool
Whether the camera has been initialized and is ready to use.
no setter
onBarcodesScanned BarcodesScannedCallback?
Callback invoked when barcodes are scanned in the camera feed.
getter/setter pair
onFaceDetected FaceDetectedCallback?
Callback invoked when a face is detected in the camera feed.
getter/setter pair
onTextRecognized TextRecognizedCallback?
Callback invoked when text is recognized in the camera feed.
getter/setter pair
paused bool
Whether the camera is currently paused.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size → (int, int)
The size of the camera preview in pixels as (width, height).
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
captureImage({bool immediate = false}) Future<Uint8List?>
Captures an image from the camera.
dispose() Future<void>
Disposes of the camera and releases associated resources.
override
initialize() Future<void>
Initializes the camera and prepares it for use.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited