id property
int?
get
id
A unique ID referring to this camera instance.
Returns null if the camera has not been initialized yet.
Implementation
int? get id => _id;
A unique ID referring to this camera instance.
Returns null if the camera has not been initialized yet.
int? get id => _id;